==> ah-formbuilder-1.0.15.tgz: package/es/utils/validations/ValidateField.js <==
export default (function (field, fields, currentLang) {
  return new Promise(function (resolve, reject) {
    var _field$config2, _field$config3;

    var errors = {};

    var machineNames = _.map(fields, function (field, uuid) {
      if (uuid !== field.uuid) {
        return field.machineName;
      }
    });

    if (['text', 'select', 'checkbox', 'radio', 'date', 'file', 'survey', 'quiz', 'signature', 'list', 'section'].includes(field.type)) {
      if (!field.name || field.name === '') {
        errors.name = currentLang === 'en' ? 'Name is required' : 'مطلوب اسم';
      }

      if (!field.machineName || field.machineName === '') {
        errors.machineName = currentLang === 'en' ? 'Machine Name is required' : 'اسم الجهاز مطلوب';
      } else if (machineNames.includes(field.machineName)) {
        errors.machineName = currentLang === 'en' ? 'This Machine Name already exists' : 'اسم الجهاز هذا موجود بالفعل';
      }

      if (field.config.isConditionalEnabled) {
        var conditionErrors = validateConditional(field.config.conditionalLogic.conditions);

        if (conditionErrors.length) {
          errors.conditionalLogic = conditionErrors;
        }
      }

      if (field.type === 'text' && field.config.regex && field.config.regex !== '') {
        try {
          new RegExp(field.config.regex);
        } catch (e) {
          errors.regex = currentLang === 'en' ? 'Regex is not valid' : 'regex غير صالح';
        }
      }
    }

    if (field.type === 'content') {
      if (!field.config.content || field.config.content === '') {
        errors.content = currentLang === 'en' ? 'Content is required' : 'المحتوى مطلوب';
      }
    }

    if (field.type === 'select' || field.type === 'checkbox' || field.type === 'radio') {
      var _field$config, _field$config$optionR, _field$config$optionR2;

      if (!field.config.optionReferenceId || (field == null ? void 0 : (_field$config = field.config) == null ? void 0 : (_field$config$optionR = _field$config.optionRef) == null ? void 0 : (_field$config$optionR2 = _field$config$optionR.options) == null ? void 0 : _field$config$optionR2.length) === 0) {
        errors.options = currentLang === 'en' ? 'Options are required' : 'الخيارات مطلوبة';
      }
    }

    if (field.type === 'image' || field.type === 'video') {
      if (!field.config.url || field.config.url === '') {
        errors.upload = currentLang === 'en' ? 'Url or file upload is required' : 'مطلوب عنوان url أو تحميل الملف';
      } else if (!validURL(field.config.url)) {
        errors.url = currentLang === 'en' ? 'Url is not valid' : 'رابط غير صالح';
      }
    }

    if ((field == null ? void 0 : (_field$config2 = field.config) == null ? void 0 : _field$config2.shouldDateValidate) && (field == null ? void 0 : (_field$config3 = field.config) == null ? void 0 : _field$config3.dateValidations)) {
      var dateValidation = field.config.dateValidations;
      var dateErrors = {};
      var pastLimitValidation = validateDateLimits(parseInt(dateValidation.pastMin), parseInt(dateValidation.pastMax));
      var futureLimitValidation = validateDateLimits(parseInt(dateValidation.futureMin), parseInt(dateValidation.futureMax));
      if (Object.keys(pastLimitValidation).length) dateErrors.pastLimitValidation = pastLimitValidation;
      if (Object.keys(futureLimitValidation).length) dateErrors.futureLimitValidation = futureLimitValidation;
      if (Object.keys(dateErrors).length) errors.dateErrors = dateErrors;
    }

    if (_.size(errors)) {
      reject(errors);
    } else {
      resolve({});
    }
  });
});

var validateDateLimits = function validateDateLimits(min, max) {
  var dateLimitErrors = {};

  if (min >= 0) {
    if (min > max) dateLimitErrors.min = 'Min Should be less than max';
  } else {
    dateLimitErrors.min = 'min must be greater than zero';
  }

  if (max >= 0) {
    if (max < min) dateLimitErrors.max = 'Max Should be greater than min';
  } else {
    dateLimitErrors.max = 'max must be greater than zero';
  }

  return dateLimitErrors;
};

var validateConditional = function validateConditional(conditions) {
  var errors = [];
  conditions.map(function (condition, index) {
    errors[index] = {};

    if (!condition.field) {
      errors[index].field = 'Field is required';
    }

    if (!condition.operator) {
      errors[index].operator = 'Operator is required';
    }

    if (!condition.value || condition.value === '') {
      errors[index].value = 'Value is required';
    }

    if (_.size(errors[index]) === 0) {
      delete errors[index];
    }
  });
  errors = errors.filter(function (el) {
    return el != null;
  });
  return errors;
};

var validURL = function validURL(str) {
  var pattern = new RegExp('^(https?:\\/\\/)?' + // protocol
  '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
  '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
  '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
  '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
  '(\\#[-a-z\\d_]*)?$', 'i'); // fragment locator

  return !!pattern.test(str);
};

==> ah-formbuilder-1.0.22.tgz: package/es/utils/validations/ValidateField.js <==
export default (function (field, fields, currentLang) {
  return new Promise(function (resolve, reject) {
    var _field$config2, _field$config3;

    var errors = {};

    var machineNames = _.map(fields, function (item) {
      console.log(item, field);

      if (item.uuid !== field.uuid) {
        return field.machineName;
      }
    }); // console.log(machineNames, machineNames.includes(field.machineName), field, '-');


    if (['text', 'select', 'checkbox', 'radio', 'date', 'file', 'survey', 'quiz', 'signature', 'list', 'section'].includes(field.type)) {
      if (!field.name || field.name === '') {
        errors.name = currentLang === 'en' ? 'Name is required' : 'مطلوب اسم';
      }

      if (!field.machineName || field.machineName === '') {
        errors.machineName = currentLang === 'en' ? 'Machine Name is required' : 'اسم الجهاز مطلوب';
      } else if (machineNames.includes(field.machineName)) {
        errors.machineName = currentLang === 'en' ? 'This Machine Name already exists' : 'اسم الجهاز هذا موجود بالفعل';
      }

      if (field.config.isConditionalEnabled) {
        var conditionErrors = validateConditional(field.config.conditionalLogic.conditions);

        if (conditionErrors.length) {
          errors.conditionalLogic = conditionErrors;
        }
      }

      if (field.type === 'text' && field.config.regex && field.config.regex !== '') {
        try {
          new RegExp(field.config.regex);
        } catch (e) {
          errors.regex = currentLang === 'en' ? 'Regex is not valid' : 'regex غير صالح';
        }
      }
    }

    if (field.type === 'content') {
      if (!field.config.content || field.config.content === '') {
        errors.content = currentLang === 'en' ? 'Content is required' : 'المحتوى مطلوب';
      }
    }

    if (field.type === 'select' || field.type === 'checkbox' || field.type === 'radio') {
      var _field$config, _field$config$optionR, _field$config$optionR2;

      if (!field.config.optionReferenceId || (field == null ? void 0 : (_field$config = field.config) == null ? void 0 : (_field$config$optionR = _field$config.optionRef) == null ? void 0 : (_field$config$optionR2 = _field$config$optionR.options) == null ? void 0 : _field$config$optionR2.length) === 0) {
        errors.options = currentLang === 'en' ? 'Options are required' : 'الخيارات مطلوبة';
      }
    }

    if (field.type === 'image' || field.type === 'video') {
      if (!field.config.url || field.config.url === '') {
        errors.upload = currentLang === 'en' ? 'Url or file upload is required' : 'مطلوب عنوان url أو تحميل الملف';
      } else if (!validURL(field.config.url)) {
        errors.url = currentLang === 'en' ? 'Url is not valid' : 'رابط غير صالح';
      }
    }

    if ((field == null ? void 0 : (_field$config2 = field.config) == null ? void 0 : _field$config2.shouldDateValidate) && (field == null ? void 0 : (_field$config3 = field.config) == null ? void 0 : _field$config3.dateValidations)) {
      var dateValidation = field.config.dateValidations;
      var dateErrors = {};
      var pastLimitValidation = validateDateLimits(parseInt(dateValidation.pastMin), parseInt(dateValidation.pastMax));
      var futureLimitValidation = validateDateLimits(parseInt(dateValidation.futureMin), parseInt(dateValidation.futureMax));
      if (Object.keys(pastLimitValidation).length) dateErrors.pastLimitValidation = pastLimitValidation;
      if (Object.keys(futureLimitValidation).length) dateErrors.futureLimitValidation = futureLimitValidation;
      if (Object.keys(dateErrors).length) errors.dateErrors = dateErrors;
    }

    if (_.size(errors)) {
      reject(errors);
    } else {
      resolve({});
    }
  });
});

var validateDateLimits = function validateDateLimits(min, max) {
  var dateLimitErrors = {};

  if (min >= 0) {
    if (min > max) dateLimitErrors.min = 'Min Should be less than max';
  } else {
    dateLimitErrors.min = 'min must be greater than zero';
  }

  if (max >= 0) {
    if (max < min) dateLimitErrors.max = 'Max Should be greater than min';
  } else {
    dateLimitErrors.max = 'max must be greater than zero';
  }

  return dateLimitErrors;
};

var validateConditional = function validateConditional(conditions) {
  var errors = [];
  conditions.map(function (condition, index) {
    errors[index] = {};

    if (!condition.field) {
      errors[index].field = 'Field is required';
    }

    if (!condition.operator) {
      errors[index].operator = 'Operator is required';
    }

    if (!condition.value || condition.value === '') {
      errors[index].value = 'Value is required';
    }

    if (_.size(errors[index]) === 0) {
      delete errors[index];
    }
  });
  errors = errors.filter(function (el) {
    return el != null;
  });
  return errors;
};

var validURL = function validURL(str) {
  var pattern = new RegExp('^(https?:\\/\\/)?' + // protocol
  '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|' + // domain name
  '((\\d{1,3}\\.){3}\\d{1,3}))' + // OR ip (v4) address
  '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*' + // port and path
  '(\\?[;&a-z\\d%_.~+=-]*)?' + // query string
  '(\\#[-a-z\\d_]*)?$', 'i'); // fragment locator

  return !!pattern.test(str);
};
